@@ -17,6 +17,7 @@ package usbid
 
 import (
 	"bufio"
+	"errors"
 	"fmt"
 	"io"
 	"strconv"
@@ -127,7 +128,7 @@ func ParseIDs(r io.Reader) (map[ID]*Vendor, map[ClassCode]*Class, error) {
 
 		case 1:
 			if vendor == nil {
-				return fmt.Errorf("product line without vendor line")
+				return errors.New("product line without vendor line")
 			}
 
 			device = &Product{
@@ -142,7 +143,7 @@ func ParseIDs(r io.Reader) (map[ID]*Vendor, map[ClassCode]*Class, error) {
 
 		case 2:
 			if device == nil {
-				return fmt.Errorf("interface line without device line")
+				return errors.New("interface line without device line")
 			}
 
 			if device.Interface == nil {
@@ -152,7 +153,7 @@ func ParseIDs(r io.Reader) (map[ID]*Vendor, map[ClassCode]*Class, error) {
 			device.Interface[id] = name
 
 		default:
-			return fmt.Errorf("too many levels of nesting for vendor block")
+			return errors.New("too many levels of nesting for vendor block")
 		}
 
 		return nil
@@ -173,7 +174,7 @@ func ParseIDs(r io.Reader) (map[ID]*Vendor, map[ClassCode]*Class, error) {
 
 		case 1:
 			if class == nil {
-				return fmt.Errorf("subclass line without class line")
+				return errors.New("subclass line without class line")
 			}
 
 			subclass = &SubClass{
@@ -188,7 +189,7 @@ func ParseIDs(r io.Reader) (map[ID]*Vendor, map[ClassCode]*Class, error) {
 
 		case 2:
 			if subclass == nil {
-				return fmt.Errorf("protocol line without subclass line")
+				return errors.New("protocol line without subclass line")
 			}
 
 			if subclass.Protocol == nil {
@@ -198,7 +199,7 @@ func ParseIDs(r io.Reader) (map[ID]*Vendor, map[ClassCode]*Class, error) {
 			subclass.Protocol[Protocol(id)] = name
 
 		default:
-			return fmt.Errorf("too many levels of nesting for class")
+			return errors.New("too many levels of nesting for class")
 		}
 
 		return nil
